@@ -12,25 +12,26 @@ test_that("undirected graphs allow_self_loops = FALSE", {
 
   ufm <- undirected_factor_model(
     X, S,
-    expected_density = 0.1
+    expected_density = 0.1,
+    allow_self_loops = FALSE
   )
 
-  edgelist <- sample_edgelist(ufm, allow_self_loops = FALSE)
+  edgelist <- sample_edgelist(ufm,)
   expect_false(any(edgelist$from == edgelist$to))
 
-  A <- sample_sparse(ufm, allow_self_loops = FALSE)
+  A <- sample_sparse(ufm)
   expect_false(any(diag(A) > 0))
 
-  igraph <- sample_igraph(ufm, allow_self_loops = FALSE)
+  igraph <- sample_igraph(ufm)
   expect_false(any(diag(get.adjacency(igraph)) > 0))
 
   ### sampling graphs as tidygraph graphs ---------------
 
-  tbl_graph <- sample_tidygraph(ufm, allow_self_loops = FALSE)
+  tbl_graph <- sample_tidygraph(ufm)
   expect_false(any(diag(get.adjacency(tbl_graph)) > 0))
 })
 
-test_that("directed graphs poisson_edges = FALSE", {
+test_that("directed graphs allow_self_loops = FALSE", {
 
   set.seed(2)
 
@@ -45,19 +46,19 @@ test_that("directed graphs poisson_edges = FALSE", {
   S <- matrix(runif(n = k1 * k2, 0, .1), nrow = k1, ncol = k2)
   Y <- matrix(rexp(n = k2 * d, 1), nrow = d)
 
-  fm <- directed_factor_model(X, S, Y, expected_density = 0.01)
+  fm <- directed_factor_model(X, S, Y, expected_density = 0.01, allow_self_loops = FALSE)
 
-  edgelist <- sample_edgelist(fm, allow_self_loops = FALSE)
+  edgelist <- sample_edgelist(fm)
   expect_false(any(edgelist$from == edgelist$to))
 
-  A <- sample_sparse(fm, allow_self_loops = FALSE)
+  A <- sample_sparse(fm)
   expect_false(any(diag(A) > 0))
 
-  igraph <- sample_igraph(fm, allow_self_loops = FALSE)
+  igraph <- sample_igraph(fm)
   expect_false(any(diag(get.adjacency(igraph)) > 0))
 
   ### sampling graphs as tidygraph graphs ---------------
 
-  tbl_graph <- sample_tidygraph(fm, allow_self_loops = FALSE)
+  tbl_graph <- sample_tidygraph(fm)
   expect_false(any(diag(get.adjacency(tbl_graph)) > 0))
 })
